prep_for_adj <- function(data, item, group, id, weight = NULL, exclude = TRUE) {
  #############################
  ## Remove missing outcome values
  #############################
  if (length(item) == 1) {
    this_outcome_data <- data |>
      group_by(!!sym(group)) |>
      mutate(alln = n()) |>
      filter(!is.na(!!sym(item)))
  } else {
    this_outcome_data <- map_dfr(item, function(ii) {
      data |>
      group_by(!!sym(group)) |>
      mutate(alln = length(unique(!!sym(id)))) |>
      filter(!is.na(!!sym(ii))) |>
        mutate(item = ii,
               y = !!sym(ii))
    })
  }


  ####################
  ## Exclude units with 0 or 1 responses
  ####################
    this_outcome_data <- this_outcome_data |>
      group_by(!!sym(group)) |>
      mutate(usen = length(unique(!!sym(id)))) |>
      ungroup()
    if (exclude) {
      this_outcome_data <- this_outcome_data |>
        filter(usen >= 2)
    }



  ################################
  ## Check if weights are already in the dataset. If not, set them to uniformly 1.
  ################################
  if (!is.null(weight)) {
    if (!weight %in% colnames(data)) stop(glue('Weight supplied as `{weight}`, but `{weight}` not in data.'))
  } else {
    this_outcome_data <- this_outcome_data |>
      mutate(wt = 1)
  }
  this_outcome_data
}
