% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/adj_item.R
\name{adj_item}
\alias{adj_item}
\title{Case-mix Adjust Item Scores}
\usage{
adj_item(
  item,
  adjusters = NULL,
  data,
  group,
  type = NULL,
  weight = NULL,
  total_weight = NULL,
  una_mean = NULL,
  prev_coef = NULL,
  natl_means = NULL,
  id = NULL,
  write_folder = NULL,
  exclude = TRUE,
  enforce_boundaries = TRUE
)
}
\arguments{
\item{item}{A string representing the name of the item variable to be adjusted.}

\item{adjusters}{A character vector of variable names to be used as case-mix adjusters in the model. Defaults to `NULL`.}

\item{data}{A data frame containing the dataset.}

\item{group}{A string representing the name of the group or unit variable. This is the level at which scores will be reported.}

\item{type}{A string representing the name of the type variable, which may describe units of different types. Defaults to `NULL`.}

\item{weight}{A string representing the name of the weight variable, if groups are weighted. Individual weights should not be used. Defaults to `NULL`.}

\item{total_weight}{A string representing the name of the total weight variable, if groups are weighted. Defaults to `NULL`.}

\item{una_mean}{A string representing the name of the unadjusted mean variable, if unadjusted means are pre-computed and do not require computation in this dataset. Defaults to `NULL`.}

\item{prev_coef}{A data frame containing previous coefficients for adjustment. This allows for more efficient computation or applying case-mix adjustment to a new population. Defaults to `NULL`.}

\item{natl_means}{A data frame containing national means for adjusters,  if these are pre-computed. Defaults to `NULL`.}

\item{id}{A string representing the name of the individual-level ID variable. Defaults to `NULL`.}

\item{write_folder}{A string representing the directory path to write output files. Defaults to `NULL`.}

\item{exclude}{A logical value indicating whether to exclude units with small samples. Defaults to `TRUE`.}

\item{enforce_boundaries}{A logical value indicating whether to enforce boundaries on adjusted means. Defaults to `TRUE`.}
}
\value{
A data frame summarizing the adjusted means, variances, and other statistics for each group.
}
\description{
This function adjusts group-level item scores for its case mix, or the characteristics that make up the group, using a linear model approach.
}
\details{
The function performs several steps including data cleaning, calculation of unadjusted means, running a linear model, and calculating adjusted means and variances. It also writes intermediate data to files if a `write_folder` is specified.
}
\examples{
n_grps <- 10
group_ds <- tibble::tibble(grp_id = 1:n_grps,
                           grp_quality = rnorm(n_grps, sd = 2),
                           grp_n = rpois(n_grps, 5)*75 + 30)
nn <- sum(group_ds$grp_n)
individual_ds <- tibble::tibble(individual_id = 1:nn,
                                grp_id = rep(group_ds$grp_id, group_ds$grp_n),
                                x1 = rnorm(nn),
                                x2 = rnorm(nn),
                                x3 = 1*(rnorm(nn) > 1))
analysis_ds <- dplyr::inner_join(group_ds, individual_ds) |>
  dplyr::mutate(y = grp_quality + x1 - x2 - 3*x3 + rnorm(nn, sd = 0.5))

adj_item(item = 'y', adjusters = c('x1', 'x2', 'x3'), data = analysis_ds, group = 'grp_id', id = 'individual_id', enforce_boundaries = FALSE)

}
