% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compute_composite.R
\name{compute_composite}
\alias{compute_composite}
\title{Perform Case-mix Adjustment for Composite Scores}
\usage{
compute_composite(
  data,
  group,
  id,
  adjvars,
  weight = NULL,
  type = NULL,
  items,
  composite_name,
  k = 1,
  prev_coef_comp = NULL,
  write_folder = NULL
)
}
\arguments{
\item{data}{A data frame containing the dataset.}

\item{group}{A string representing the name of the unit/grouping variable.}

\item{id}{A string representing the name of the individual-level  ID variable.}

\item{adjvars}{A character vector of variable names to be used as case-mix adjusters in the model.}

\item{weight}{A string representing the name of the weight variable. Defaults to `NULL`.}

\item{type}{A string representing the name of the type variable, which may describe units of different types. Defaults to `NULL`.}

\item{items}{A character vector of item names to be included in the composite.}

\item{composite_name}{A string representing the name of the composite score.}

\item{k}{An integer specifying the that items with sample size lower than `k` should receive lower weight. Defaults to 1.}

\item{prev_coef_comp}{A data frame containing previous coefficients for composite adjustment. Defaults to `NULL`.}

\item{write_folder}{A string representing the directory path to write output files. Defaults to `NULL`.}
}
\value{
A data frame with composite scores and related statistics for each group.
}
\description{
This function computes case-mix adjusted composite scores from multiple items, adjusting for group characteristics.
}
\details{
The function prepares data, computes unadjusted and adjusted means, and calculates composite scores using specified items and adjusters. It also handles weighting and variance calculations.
}
\examples{
n_grps <- 10
group_ds <- tibble::tibble(grp_id = 1:n_grps,
                           grp_quality = rnorm(n_grps, sd = 2),
                           grp_n = rpois(n_grps, 5)*75 + 30)
nn <- sum(group_ds$grp_n)
individual_ds <- tibble::tibble(individual_id = 1:nn,
                                grp_id = rep(group_ds$grp_id, group_ds$grp_n),
                                x1 = rnorm(nn),
                                x2 = rnorm(nn),
                                x3 = 1*(rnorm(nn) > 1))
analysis_ds <- dplyr::inner_join(group_ds, individual_ds) |>
  dplyr::mutate(y1 = grp_quality + x1 - x2 - 3*x3 + rnorm(nn, sd = 0.5),
                y2 = grp_quality/2 + 0.5*x1 - 2*x2 - x3 + rnorm(nn, sd = 0.5))

compute_composite(data = analysis_ds, group = 'grp_id', id = 'individual_id', adjvars = c('x1', 'x2', 'x3'), items = c('y1', 'y2'), composite_name = 'my_composite')

}
